==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/ru/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "Шаблон $1 используется и не может быть удален");
regGS("The folder could not be deleted.", "Папка не может быть удалена.");
regGS("The directory must be empty", "Папка должна быть пуста");
regGS("Create new folder", "Создать новую папку");
regGS("Upload template", "Загрузить шаблон");
regGS("Creating new folder", "Создание новой папки");
regGS("You do not have the right to create new folders.", "Вы не имеете права создания новых папок.");
regGS("The folder $1 could not be created", "Невозможно создать папку $1");
regGS("A file or folder having the name $1 already exists", "Файл или папка с названием $1 уже существует");
regGS("You do not have the right to delete templates.", "Вы не имеете права удаления шаблонов.");
regGS("Are you sure you want to delete the folder $1 from $2?", "Вы уверены, что хотите удалить папку $1 из $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Вы уверены, что хотите удалить шаблон $1 из папки $2?");
regGS("Deleting template", "Удаление шаблона");
regGS("Deleting folder", "Удаление папки");
regGS("Template $1 was deleted", "Шаблон $1 был удален");
regGS("Delete folder", "Удалить папку");
regGS("Folders", "Папки");
regGS("No folders.", "Нет папок.");
regGS("Files", "Файлы");
regGS("No templates.", "Нет шаблонов");
regGS("Uploading template", "Загрузка шаблонов");
regGS("File", "Файл");
regGS("Create new template", "Создать новый шаблон");
regGS("Creating new template", "Создание нового шаблона");
regGS("Duplicate template", "Дублировать шаблон");
regGS("Edit template", "Редактировать шаблон");
regGS("The template $1 has been created.", "Шаблон $1 был создан.");
regGS("Do you want to edit the template ?", "Хотите ли вы редактировать шаблон?");
regGS("The template $1 could not be created.", "Невозможно создать шаблон $1");
regGS("Template $1 was changed", "Шаблон $1 был изменен");
regGS("New template $1 was created", "Был создан новый шаблон $1");
regGS("Template $1 was duplicated into $2", "Шаблон $1 был дублирован в $2");
regGS("Template charset", "Кодовая таблица шаблона");
regGS("Select a language/character set", "Выберите язык/кодовую таблицу");
regGS("All languages", "Все языки");
regGS("You do not have the right to modify templates.", "Вы не имеет а права модифицировать шаблон.");
regGS("Invalid template file $1", "Неправильный шаблон $1");
regGS("You do not have the right to create folders.", "Вы не имеет а права создавать папки.");
regGS("You do not have the right to upload templates.", "Вы не имеет а права загружать шаблоны.");
regGS("You do not have the right to create templates.", "Вы не имеет а права создавать шаблоны.");
regGS("Duplicate file", "Дублировать файл");
regGS("Delete file", "Удалить файл");
regGS("Unable to save the template '$1' to the path '$2'.", "Невозможно  сохранить шаблон '$1' в папку '$2'.");
regGS("Please check if the user '$1' has permission to write in this directory.", "Пожалуйста проверьте, что пользователь '$1' имел право записи в эту папку.");
regGS("Unable to delete the template '$1' in the path '$2'.", "Невозможно удалить шаблон '$1' в папке '$2'.");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/ru/templates.php <==
<?php 
regGS("Template ID:", "ID шаблона:");
regGS("Template ID", "ID шаблона");
regGS("Template $1 no longer exists!", "Шаблон $1 больше не существует!");
regGS("New template $1 created", "Создан новый шаблон $1");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "Если указанные файл текстовый, вы можете конвертировать кодировку с помощью выпадающего меню.");
regGS("Directory $1 was deleted", "Папка $1 была удалена");
regGS("Directory $1 created.", "Папка $1 была создана.");
regGS("You must select a file to upload.", "Вы должны указать файл для загрузки.");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "Вы можете только заместить файл файлом того же типа. Оригинальный файл имеет тип \"$1\", а загруженный - \"$2\".");
regGS("Unable to save the file '$1' to the path '$2'.", "Невозможно сохранить файл '$1' в '$2'.");
regGS("Replace file:", "Заменить файл:");
regGS("Replace", "Заменить:");
regGS("File \"$1\" uploaded.", "Файл \"$1\" загружен.");
regGS("File \"$1\" replaced.", "Файл \"$1\" заменен.");
regGS("The folder name can't be '..' or '.'", "Название папки не может быть '..' или '.'");
regGS("The template '$1' was saved successfully.", "Шаблон '$1' был успешно сохранен.");
regGS("The template $1 is in use and can not be deleted.", "Шаблон $1 используется и не может быть удален");
regGS("Create new folder", "Создать новую папку");
regGS("Upload template", "Загрузить шаблон");
regGS("You do not have the right to create new folders.", "Вы не имеете права создания новых папок.");
regGS("A file or folder having the name $1 already exists", "Файл или папка с названием $1 уже существует");
regGS("You do not have the right to delete templates.", "Вы не имеете права удаления шаблонов.");
regGS("Are you sure you want to delete the folder $1 from $2?", "Вы уверены, что хотите удалить папку $1 из $2?");
regGS("Are you sure you want to delete the template $1 from folder $2?", "Вы уверены, что хотите удалить шаблон $1 из папки $2?");
regGS("Template $1 was deleted", "Шаблон $1 был удален");
regGS("Delete folder", "Удалить папку");
regGS("Folders", "Папки");
regGS("No folders.", "Нет папок.");
regGS("Files", "Файлы");
regGS("No templates.", "Нет шаблонов");
regGS("File", "Файл");
regGS("Create new template", "Создать новый шаблон");
regGS("Duplicate template", "Дублировать шаблон");
regGS("Edit template", "Редактировать шаблон");
regGS("The template $1 could not be created.", "Невозможно создать шаблон $1");
regGS("Template $1 was changed", "Шаблон $1 был изменен");
regGS("Template $1 was duplicated into $2", "Шаблон $1 был дублирован в $2");
regGS("Template charset", "Кодовая таблица шаблона");
regGS("Select a language/character set", "Выберите язык/кодовую таблицу");
regGS("All languages", "Все языки");
regGS("You do not have the right to modify templates.", "Вы не имеет а права модифицировать шаблон.");
regGS("Invalid template file $1", "Неправильный шаблон $1");
regGS("You do not have the right to create folders.", "Вы не имеет а права создавать папки.");
regGS("You do not have the right to upload templates.", "Вы не имеет а права загружать шаблоны.");
regGS("You do not have the right to create templates.", "Вы не имеет а права создавать шаблоны.");
regGS("Duplicate file", "Дублировать файл");
regGS("Delete file", "Удалить файл");
regGS("Please check if the user '$1' has permission to write in this directory.", "Пожалуйста проверьте, что пользователь '$1' имел право записи в эту папку.");
?>
